@@ -23,8 +23,8 @@
 #include <QQuickItem>
 
 #include <Plasma/Corona>
-#include <kactioncollection.h>
 #include <QAction>
+#include <kactioncollection.h>
 
 SystemTrayContainer::SystemTrayContainer(QObject *parent, const QVariantList &args)
     : Plasma::Applet(parent, args)
@@ -42,7 +42,7 @@ void SystemTrayContainer::init()
 {
     Applet::init();
 
-    //in the first creation we immediately create the systray: so it's accessible during desktop scripting
+    // in the first creation we immediately create the systray: so it's accessible during desktop scripting
     uint id = config().readEntry("SystrayContainmentId", 0);
 
     if (id == 0) {
@@ -75,7 +75,7 @@ void SystemTrayContainer::ensureSystrayExists()
             }
         }
         qCDebug(SYSTEM_TRAY_CONTAINER) << "Containment id" << id << "that used to be a system tray was deleted";
-        //id = 0;
+        // id = 0;
     }
 
     if (!m_innerContainment) {
@@ -89,29 +89,31 @@ void SystemTrayContainer::ensureSystrayExists()
 
     m_innerContainment->setParent(this);
     connect(containment(), &Plasma::Containment::screenChanged, m_innerContainment.data(), &Plasma::Containment::reactToScreenChange);
+
     if (formFactor() == Plasma::Types::Horizontal || formFactor() == Plasma::Types::Vertical) {
         m_innerContainment->setFormFactor(formFactor());
     } else {
         m_innerContainment->setFormFactor(Plasma::Types::Horizontal);
     }
-    m_innerContainment->setLocation(location());
+
+    if (m_innerContainment) {
+        m_innerContainment->setLocation(location());
+    }
 
     m_internalSystray = m_innerContainment->property("_plasma_graphicObject").value<QQuickItem *>();
     emit internalSystrayChanged();
 
     actions()->addAction("configure", m_innerContainment->actions()->action("configure"));
-    connect(m_innerContainment.data(), &Plasma::Containment::configureRequested, this,
-        [this](Plasma::Applet *applet) {
-            emit containment()->configureRequested(applet);
-        }
-    );
+    connect(m_innerContainment.data(), &Plasma::Containment::configureRequested, this, [this](Plasma::Applet *applet) {
+        emit containment()->configureRequested(applet);
+    });
 
     if (m_internalSystray) {
-        //don't let internal systray manage context menus
+        // don't let internal systray manage context menus
         m_internalSystray->setAcceptedMouseButtons(Qt::NoButton);
     }
 
-    //replace internal remove action with ours
+    // replace internal remove action with ours
     m_innerContainment->actions()->addAction("remove", actions()->action("remove"));
 }
 
@@ -122,6 +124,7 @@ void SystemTrayContainer::constraintsEvent(Plasma::Types::Constraints constraint
             m_innerContainment->setLocation(location());
         }
     }
+
     if (constraints & Plasma::Types::FormFactorConstraint) {
         if (m_innerContainment) {
             if (formFactor() == Plasma::Types::Horizontal || formFactor() == Plasma::Types::Vertical) {
