@@ -19,7 +19,6 @@
 
 #include "activityengine.h"
 #include "activityservice.h"
-#include "ActivityRankingInterface.h"
 
 #include <kactivities/controller.h>
 #include <kactivities/info.h>
@@ -30,7 +29,7 @@
 #define ACTIVITYMANAGER_SERVICE "org.kde.kactivitymanagerd"
 #define ACTIVITYRANKING_OBJECT "/ActivityRanking"
 
-ActivityEngine::ActivityEngine(QObject* parent, const QVariantList& args)
+ActivityEngine::ActivityEngine(QObject *parent, const QVariantList &args)
     : Plasma::DataEngine(parent, args)
 {
     Q_UNUSED(args);
@@ -40,14 +39,14 @@ ActivityEngine::ActivityEngine(QObject* parent, const QVariantList& args)
 void ActivityEngine::init()
 {
     if (qApp->applicationName() == QLatin1String("plasma-netbook")) {
-        //hack for the netbook
-        //FIXME can I read a setting or something instead?
+        // hack for the netbook
+        // FIXME can I read a setting or something instead?
     } else {
         m_activityController = new KActivities::Controller(this);
         m_currentActivity = m_activityController->currentActivity();
-        QStringList activities = m_activityController->activities();
-        //setData("allActivities", activities);
-        foreach (const QString &id, activities) {
+        const QStringList activities = m_activityController->activities();
+        // setData("allActivities", activities);
+        for (const QString &id : activities) {
             insertActivity(id);
         }
 
@@ -55,19 +54,17 @@ void ActivityEngine::init()
         connect(m_activityController, &KActivities::Controller::activityRemoved, this, &ActivityEngine::activityRemoved);
         connect(m_activityController, &KActivities::Controller::currentActivityChanged, this, &ActivityEngine::currentActivityChanged);
 
-        //some convenience sources for times when checking every activity source would suck
-        //it starts with _ so that it can easily be filtered out of sources()
-        //maybe I should just make it not included in sources() instead?
+        // some convenience sources for times when checking every activity source would suck
+        // it starts with _ so that it can easily be filtered out of sources()
+        // maybe I should just make it not included in sources() instead?
         m_runningActivities = m_activityController->activities(KActivities::Info::Running);
         setData(QStringLiteral("Status"), QStringLiteral("Current"), m_currentActivity);
         setData(QStringLiteral("Status"), QStringLiteral("Running"), m_runningActivities);
 
-        m_watcher = new QDBusServiceWatcher(
-            ACTIVITYMANAGER_SERVICE,
-            QDBusConnection::sessionBus(),
-            QDBusServiceWatcher::WatchForRegistration
-                | QDBusServiceWatcher::WatchForUnregistration,
-            this);
+        m_watcher = new QDBusServiceWatcher(ACTIVITYMANAGER_SERVICE,
+                                            QDBusConnection::sessionBus(),
+                                            QDBusServiceWatcher::WatchForRegistration | QDBusServiceWatcher::WatchForUnregistration,
+                                            this);
 
         connect(m_watcher, &QDBusServiceWatcher::serviceRegistered, this, &ActivityEngine::enableRanking);
         connect(m_watcher, &QDBusServiceWatcher::serviceUnregistered, this, &ActivityEngine::disableRanking);
@@ -80,7 +77,7 @@ void ActivityEngine::init()
 
 void ActivityEngine::insertActivity(const QString &id)
 {
-    //id -> name, icon, state
+    // id -> name, icon, state
     KActivities::Info *activity = new KActivities::Info(id, this);
     m_activities[id] = activity;
     setData(id, QStringLiteral("Name"), activity->name());
@@ -89,21 +86,21 @@ void ActivityEngine::insertActivity(const QString &id)
 
     QString state;
     switch (activity->state()) {
-        case KActivities::Info::Running:
-            state = QLatin1String("Running");
-            break;
-        case KActivities::Info::Starting:
-            state = QLatin1String("Starting");
-            break;
-        case KActivities::Info::Stopping:
-            state = QLatin1String("Stopping");
-            break;
-        case KActivities::Info::Stopped:
-            state = QLatin1String("Stopped");
-            break;
-        case KActivities::Info::Invalid:
-        default:
-            state = QLatin1String("Invalid");
+    case KActivities::Info::Running:
+        state = QLatin1String("Running");
+        break;
+    case KActivities::Info::Starting:
+        state = QLatin1String("Starting");
+        break;
+    case KActivities::Info::Stopping:
+        state = QLatin1String("Stopping");
+        break;
+    case KActivities::Info::Stopped:
+        state = QLatin1String("Stopped");
+        break;
+    case KActivities::Info::Invalid:
+    default:
+        state = QLatin1String("Invalid");
     }
     setData(id, QStringLiteral("State"), state);
     setData(id, QStringLiteral("Score"), m_activityScores.value(id));
@@ -121,11 +118,7 @@ void ActivityEngine::disableRanking()
 
 void ActivityEngine::enableRanking()
 {
-    m_activityRankingClient = new org::kde::ActivityManager::ActivityRanking(
-            ACTIVITYMANAGER_SERVICE,
-            ACTIVITYRANKING_OBJECT,
-            QDBusConnection::sessionBus()
-        );
+    m_activityRankingClient = new org::kde::ActivityManager::ActivityRanking(ACTIVITYMANAGER_SERVICE, ACTIVITYRANKING_OBJECT, QDBusConnection::sessionBus());
     connect(m_activityRankingClient, &org::kde::ActivityManager::ActivityRanking::rankingChanged, this, &ActivityEngine::rankingChanged);
 
     QDBusMessage msg = QDBusMessage::createMethodCall(ACTIVITYMANAGER_SERVICE,
@@ -161,7 +154,7 @@ void ActivityEngine::setActivityScores(const ActivityDataList &activities)
     QSet<QString> presentActivities;
     m_activityScores.clear();
 
-    foreach (const ActivityData &activity, activities) {
+    for (const ActivityData &activity : activities) {
         if (m_activities.contains(activity.id)) {
             setData(activity.id, QStringLiteral("Score"), activity.score);
         }
@@ -169,7 +162,8 @@ void ActivityEngine::setActivityScores(const ActivityDataList &activities)
         m_activityScores[activity.id] = activity.score;
     }
 
-    foreach (const QString &activityId, m_activityController->activities()) {
+    const auto controllerActivities = m_activityController->activities();
+    for (const QString &activityId : controllerActivities) {
         if (!presentActivities.contains(activityId) && m_activities.contains(activityId)) {
             setData(activityId, QStringLiteral("Score"), 0);
         }
@@ -203,7 +197,7 @@ void ActivityEngine::currentActivityChanged(const QString &id)
 
 void ActivityEngine::activityDataChanged()
 {
-    KActivities::Info *activity = qobject_cast<KActivities::Info*>(sender());
+    KActivities::Info *activity = qobject_cast<KActivities::Info *>(sender());
     if (!activity) {
         return;
     }
@@ -215,28 +209,28 @@ void ActivityEngine::activityDataChanged()
 
 void ActivityEngine::activityStateChanged()
 {
-    KActivities::Info *activity = qobject_cast<KActivities::Info*>(sender());
+    KActivities::Info *activity = qobject_cast<KActivities::Info *>(sender());
     const QString id = activity->id();
     if (!activity) {
         return;
     }
     QString state;
     switch (activity->state()) {
-        case KActivities::Info::Running:
-            state = QLatin1String("Running");
-            break;
-        case KActivities::Info::Starting:
-            state = QLatin1String("Starting");
-            break;
-        case KActivities::Info::Stopping:
-            state = QLatin1String("Stopping");
-            break;
-        case KActivities::Info::Stopped:
-            state = QLatin1String("Stopped");
-            break;
-        case KActivities::Info::Invalid:
-        default:
-            state = QLatin1String("Invalid");
+    case KActivities::Info::Running:
+        state = QLatin1String("Running");
+        break;
+    case KActivities::Info::Starting:
+        state = QLatin1String("Starting");
+        break;
+    case KActivities::Info::Stopping:
+        state = QLatin1String("Stopping");
+        break;
+    case KActivities::Info::Stopped:
+        state = QLatin1String("Stopped");
+        break;
+    case KActivities::Info::Invalid:
+    default:
+        state = QLatin1String("Invalid");
     }
     setData(id, QStringLiteral("State"), state);
 
@@ -251,10 +245,9 @@ void ActivityEngine::activityStateChanged()
     setData(QStringLiteral("Status"), QStringLiteral("Running"), m_runningActivities);
 }
 
-
 Plasma::Service *ActivityEngine::serviceForSource(const QString &source)
 {
-    //FIXME validate the name
+    // FIXME validate the name
     ActivityService *service = new ActivityService(m_activityController, source);
     service->setParent(this);
     return service;
