@@ -21,18 +21,21 @@
 
 #include <QDebug>
 
-#include <KLocalizedString>
-#include <kmacroexpander.h>
 #include <KIO/CommandLauncherJob>
+#include <KLocalizedString>
 #include <KNotificationJobUiDelegate>
-#include <solid/storageaccess.h>
+#include <kmacroexpander.h>
 #include <solid/block.h>
+#include <solid/storageaccess.h>
 
 class MacroExpander : public KMacroExpanderBase
 {
 public:
     MacroExpander(const Solid::Device &device)
-        : KMacroExpanderBase('%'), m_device(device) {}
+        : KMacroExpanderBase('%')
+        , m_device(device)
+    {
+    }
 
 protected:
     int expandEscapedMacro(const QString &str, int pos, QStringList &ret) override;
@@ -68,7 +71,7 @@ QString DeviceServiceAction::id() const
     if (m_service.name().isEmpty() && m_service.exec().isEmpty()) {
         return QString();
     } else {
-        return "#Service:"+m_service.name()+m_service.exec();
+        return "#Service:" + m_service.name() + m_service.exec();
     }
 }
 
@@ -77,8 +80,7 @@ void DeviceServiceAction::execute(Solid::Device &device)
     new DelayedExecutor(m_service, device);
 }
 
-void DelayedExecutor::_k_storageSetupDone(Solid::ErrorType error, QVariant errorData,
-                                          const QString &udi)
+void DelayedExecutor::_k_storageSetupDone(Solid::ErrorType error, QVariant errorData, const QString &udi)
 {
     Q_UNUSED(errorData);
 
@@ -87,7 +89,7 @@ void DelayedExecutor::_k_storageSetupDone(Solid::ErrorType error, QVariant error
     }
 }
 
-void DeviceServiceAction::setService(const KServiceAction& service)
+void DeviceServiceAction::setService(const KServiceAction &service)
 {
     DeviceAction::setIconName(service.icon());
     DeviceAction::setLabel(service.text());
@@ -102,7 +104,7 @@ KServiceAction DeviceServiceAction::service() const
 
 int MacroExpander::expandEscapedMacro(const QString &str, int pos, QStringList &ret)
 {
-    ushort option = str[pos+1].unicode();
+    ushort option = str[pos + 1].unicode();
 
     switch (option) {
     case 'f': // Filepath
@@ -110,8 +112,7 @@ int MacroExpander::expandEscapedMacro(const QString &str, int pos, QStringList &
         if (m_device.is<Solid::StorageAccess>()) {
             ret << m_device.as<Solid::StorageAccess>()->filePath();
         } else {
-            qWarning() << "DeviceServiceAction::execute: " << m_device.udi()
-                       << " is not a StorageAccess device";
+            qWarning() << "DeviceServiceAction::execute: " << m_device.udi() << " is not a StorageAccess device";
         }
         break;
     case 'd': // Device node
@@ -119,8 +120,7 @@ int MacroExpander::expandEscapedMacro(const QString &str, int pos, QStringList &
         if (m_device.is<Solid::Block>()) {
             ret << m_device.as<Solid::Block>()->device();
         } else {
-            qWarning() << "DeviceServiceAction::execute: " << m_device.udi()
-                       << " is not a Block device";
+            qWarning() << "DeviceServiceAction::execute: " << m_device.udi() << " is not a Block device";
         }
         break;
     case 'i': // UDI
@@ -139,12 +139,10 @@ int MacroExpander::expandEscapedMacro(const QString &str, int pos, QStringList &
 DelayedExecutor::DelayedExecutor(const KServiceAction &service, Solid::Device &device)
     : m_service(service)
 {
-    if (device.is<Solid::StorageAccess>()
-            && !device.as<Solid::StorageAccess>()->isAccessible()) {
+    if (device.is<Solid::StorageAccess>() && !device.as<Solid::StorageAccess>()->isAccessible()) {
         Solid::StorageAccess *access = device.as<Solid::StorageAccess>();
 
-        connect(access, &Solid::StorageAccess::setupDone,
-                this, &DelayedExecutor::_k_storageSetupDone);
+        connect(access, &Solid::StorageAccess::setupDone, this, &DelayedExecutor::_k_storageSetupDone);
 
         access->setup();
     } else {
