@@ -29,8 +29,9 @@
 #include <QHash>
 #include <QPair>
 
-using InhibitionInfo = QPair<QString, QString>;
+class SessionManagement;
 
+using InhibitionInfo = QPair<QString, QString>;
 
 /**
  * This class provides runtime information about the battery and AC status
@@ -41,27 +42,28 @@ class PowermanagementEngine : public Plasma::DataEngine
     Q_OBJECT
 
 public:
-    PowermanagementEngine( QObject* parent, const QVariantList& args );
+    PowermanagementEngine(QObject *parent, const QVariantList &args);
     ~PowermanagementEngine() override;
     QStringList sources() const override;
-    Plasma::Service* serviceForSource(const QString &source) override;
+    Plasma::Service *serviceForSource(const QString &source) override;
+
 protected:
     bool sourceRequestEvent(const QString &name) override;
     bool updateSourceEvent(const QString &source) override;
     void init();
 
 private Q_SLOTS:
-    void updateBatteryChargeState(int newState, const QString& udi);
-    void updateBatteryPresentState(bool newState, const QString& udi);
-    void updateBatteryChargePercent(int newValue, const QString& udi);
-    void updateBatteryEnergy(double newValue, const QString& udi);
-    void updateBatteryPowerSupplyState(bool newState, const QString& udi);
+    void updateBatteryChargeState(int newState, const QString &udi);
+    void updateBatteryPresentState(bool newState, const QString &udi);
+    void updateBatteryChargePercent(int newValue, const QString &udi);
+    void updateBatteryEnergy(double newValue, const QString &udi);
+    void updateBatteryPowerSupplyState(bool newState, const QString &udi);
     void updateAcPlugState(bool onBattery);
     void updateBatteryNames();
     void updateOverallBattery();
 
-    void deviceRemoved(const QString& udi);
-    void deviceAdded(const QString& udi);
+    void deviceRemoved(const QString &udi);
+    void deviceAdded(const QString &udi);
     void batteryRemainingTimeChanged(qulonglong time);
     void screenBrightnessChanged(int brightness);
     void maximumScreenBrightnessChanged(int maximumBrightness);
@@ -79,9 +81,10 @@ private:
 
     QStringList m_sources;
 
-    QHash<QString, QString> m_batterySources;  // <udi, Battery0>
+    QHash<QString, QString> m_batterySources; // <udi, Battery0>
     QHash<QString, QPair<QString, QString>> m_applicationInfo; // <appname, <pretty name, icon>>
+
+    SessionManagement *m_session;
 };
 
-
 #endif
