@@ -35,7 +35,7 @@ typedef QSharedPointer<const HistoryItem> HistoryItemConstPtr;
 class HistoryItem
 {
 public:
-    explicit HistoryItem(const QByteArray& uuid);
+    explicit HistoryItem(const QByteArray &uuid);
     virtual ~HistoryItem();
 
     /**
@@ -48,7 +48,8 @@ public:
     /**
      * @return uuid of current item.
      */
-    const QByteArray& uuid() const {
+    const QByteArray &uuid() const
+    {
         return m_uuid;
     }
 
@@ -57,35 +58,35 @@ public:
      * A text would be returned as a null pixmap,
      * which is also the default implementation
      */
-    inline virtual const QPixmap& image() const;
+    inline virtual const QPixmap &image() const;
 
     /**
      * Returns a pointer to a QMimeData suitable for QClipboard::setMimeData().
      */
-    virtual QMimeData* mimeData() const = 0;
+    virtual QMimeData *mimeData() const = 0;
 
     /**
      * Write object on datastream
      */
-    virtual void write( QDataStream& stream ) const = 0;
+    virtual void write(QDataStream &stream) const = 0;
 
     /**
      * Equality.
      */
-    virtual bool operator==(const HistoryItem& rhs) const = 0;
+    virtual bool operator==(const HistoryItem &rhs) const = 0;
 
     /**
      * Create an HistoryItem from MimeSources (i.e., clipboard data)
      * returns null if create fails (e.g, unsupported mimetype)
      */
-    static HistoryItemPtr create( const QMimeData* data );
+    static HistoryItemPtr create(const QMimeData *data);
 
     /**
      * Create an HistoryItem from data stream (i.e., disk file)
      * returns null if creation fails. In this case, the datastream
      * is left in an undefined state.
      */
-    static HistoryItemPtr create( QDataStream& dataStream );
+    static HistoryItemPtr create(QDataStream &dataStream);
 
     /**
      * previous item's uuid
@@ -108,22 +109,21 @@ private:
     QByteArray m_uuid;
 };
 
-inline
-const QPixmap& HistoryItem::image() const {
+inline const QPixmap &HistoryItem::image() const
+{
     static QPixmap nullPixmap;
     return nullPixmap;
 }
 
-inline
-QDataStream& operator<<( QDataStream& lhs, HistoryItem const * const rhs ) {
-    if ( rhs ) {
-        rhs->write( lhs );
+inline QDataStream &operator<<(QDataStream &lhs, HistoryItem const *const rhs)
+{
+    if (rhs) {
+        rhs->write(lhs);
     }
     return lhs;
-
 }
 
-Q_DECLARE_METATYPE(HistoryItem*)
+Q_DECLARE_METATYPE(HistoryItem *)
 Q_DECLARE_METATYPE(HistoryItemPtr)
 Q_DECLARE_METATYPE(HistoryItemConstPtr)
 
