@@ -16,24 +16,24 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QApplication>
 #include <KLocalizedString>
+#include <QApplication>
 
-#include <QCommandLineParser>
 #include <QAction>
-#include <QUrl>
+#include <QCommandLineParser>
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QDebug>
 #include <QQuickWindow>
 #include <QSessionManager>
-#include <QDBusMessage>
-#include <QDBusConnection>
+#include <QUrl>
 
-#include <KAuthorized>
 #include <KAboutData>
+#include <KAuthorized>
 #include <KDBusService>
 
-#include <kdeclarative/qmlobject.h>
 #include <KQuickAddons/QtQuickSettings>
+#include <kdeclarative/qmlobject.h>
 
 #include <kworkspace.h>
 
@@ -59,22 +59,16 @@ int main(int argc, char **argv)
 
     KQuickAddons::QtQuickSettings::init();
 
-//     TODO: Make it a QGuiApplication once we don't depend on KDELibs4Support
-//     QGuiApplication app(argc, argv);
+    //     TODO: Make it a QGuiApplication once we don't depend on KDELibs4Support
+    //     QGuiApplication app(argc, argv);
 
-    KAboutData aboutData(QStringLiteral("krunner"),
-        i18n("krunner"),
-        QStringLiteral(PROJECT_VERSION),
-        i18n("Run Command interface"),
-        KAboutLicense::GPL);
+    KAboutData aboutData(QStringLiteral("krunner"), i18n("krunner"), QStringLiteral(PROJECT_VERSION), i18n("Run Command interface"), KAboutLicense::GPL);
 
     KAboutData::setApplicationData(aboutData);
     app.setQuitOnLastWindowClosed(false);
 
-    QCommandLineOption clipboardOption({QStringLiteral("c"), QStringLiteral("clipboard")},
-                                        i18n("Use the clipboard contents as query for KRunner"));
-    QCommandLineOption daemonOption({QStringLiteral("d"), QStringLiteral("daemon")},
-                                        i18n("Start KRunner in the background, don't show it."));
+    QCommandLineOption clipboardOption({QStringLiteral("c"), QStringLiteral("clipboard")}, i18n("Use the clipboard contents as query for KRunner"));
+    QCommandLineOption daemonOption({QStringLiteral("d"), QStringLiteral("daemon")}, i18n("Start KRunner in the background, don't show it."));
     QCommandLineOption replaceOption({QStringLiteral("replace")}, i18n("Replace an existing instance"));
 
     parser.addOption(clipboardOption);
