@@ -25,25 +25,24 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include "greeter.h"
 
+#include <QApplication>
 #include <QDebug>
 #include <QScreen>
-#include <QApplication>
 
 #include "shutdowndlg.h"
 
-#include "logoutpromptadaptor.h"
 #include "ksmserveriface.h"
+#include "logoutpromptadaptor.h"
 
 #include <KQuickAddons/QtQuickSettings>
 #include <KWindowSystem>
 
 #include <KWayland/Client/connection_thread.h>
-#include <KWayland/Client/registry.h>
 #include <KWayland/Client/plasmashell.h>
+#include <KWayland/Client/registry.h>
 
-Greeter::Greeter(bool shutdownAllowed)
+Greeter::Greeter()
     : QObject()
-    , m_shutdownAllowed(shutdownAllowed)
     , m_waylandPlasmaShell(nullptr)
 {
     new LogoutPromptAdaptor(this);
@@ -68,11 +67,9 @@ void Greeter::setupWaylandIntegration()
     }
     Registry *registry = new Registry(this);
     registry->create(connection);
-    connect(registry, &Registry::plasmaShellAnnounced, this,
-        [this, registry] (quint32 name, quint32 version) {
-            m_waylandPlasmaShell = registry->createPlasmaShell(name, version, this);
-        }
-    );
+    connect(registry, &Registry::plasmaShellAnnounced, this, [this, registry](quint32 name, quint32 version) {
+        m_waylandPlasmaShell = registry->createPlasmaShell(name, version, this);
+    });
     registry->setup();
     connection->roundtrip();
 }
@@ -81,17 +78,17 @@ void Greeter::init()
 {
     setupWaylandIntegration();
     const auto screens = qApp->screens();
-    for (QScreen *screen: screens) {
+    for (QScreen *screen : screens) {
         adoptScreen(screen);
     }
     connect(qApp, &QGuiApplication::screenAdded, this, &Greeter::adoptScreen);
     m_running = true;
 }
 
-void Greeter::adoptScreen(QScreen* screen)
+void Greeter::adoptScreen(QScreen *screen)
 {
     // TODO: last argument is the theme, maybe add command line option for it?
-    KSMShutdownDlg *w = new KSMShutdownDlg(nullptr, m_shutdownAllowed, m_shutdownType, m_waylandPlasmaShell);
+    KSMShutdownDlg *w = new KSMShutdownDlg(nullptr, m_shutdownType, m_waylandPlasmaShell);
     w->installEventFilter(this);
     m_dialogs << w;
 
@@ -100,9 +97,7 @@ void Greeter::adoptScreen(QScreen* screen)
         w->deleteLater();
     });
     connect(w, &KSMShutdownDlg::rejected, this, &Greeter::rejected);
-    connect(w, &KSMShutdownDlg::accepted, this, [w]() {
-        OrgKdeKSMServerInterfaceInterface ksmserver(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"), QDBusConnection::sessionBus());
-        ksmserver.logout(KWorkSpace::ShutdownConfirmNo, w->shutdownType(), KWorkSpace::ShutdownModeDefault);
+    connect(w, &KSMShutdownDlg::accepted, this, []() {
         QApplication::exit(1);
     });
     w->setScreen(screen);
@@ -117,10 +112,10 @@ void Greeter::rejected()
 
 bool Greeter::eventFilter(QObject *watched, QEvent *event)
 {
-    if (qobject_cast<KSMShutdownDlg*>(watched)) {
+    if (qobject_cast<KSMShutdownDlg *>(watched)) {
         if (event->type() == QEvent::MouseButtonPress) {
             // check that the position is on no window
-            QMouseEvent *me = static_cast<QMouseEvent*>(event);
+            QMouseEvent *me = static_cast<QMouseEvent *>(event);
             for (auto it = m_dialogs.constBegin(); it != m_dialogs.constEnd(); ++it) {
                 if ((*it)->geometry().contains(me->globalPos())) {
                     return false;
@@ -159,5 +154,3 @@ void Greeter::promptReboot()
     m_shutdownType = KWorkSpace::ShutdownTypeReboot;
     init();
 }
-
-
