@@ -24,17 +24,18 @@
 #include <QDebug>
 #include <QIcon>
 
-#include <KProcess>
 #include <KAuth>
 #include <KLocalizedString>
+#include <KProcess>
 
-#include <processcore/processes.h>
 #include <processcore/process.h>
+#include <processcore/processes.h>
 
 K_EXPORT_PLASMA_RUNNER_WITH_JSON(KillRunner, "plasma-runner-kill.json")
 
-KillRunner::KillRunner(QObject *parent, const QVariantList &args)
-        : Plasma::AbstractRunner(parent, args), m_processes(nullptr)
+KillRunner::KillRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : Plasma::AbstractRunner(parent, metaData, args)
+    , m_processes(nullptr)
 {
     setObjectName(QStringLiteral("Kill Runner"));
 
@@ -52,7 +53,6 @@ KillRunner::KillRunner(QObject *parent, const QVariantList &args)
 
 KillRunner::~KillRunner() = default;
 
-
 void KillRunner::reloadConfiguration()
 {
     KConfigGroup grp = config();
@@ -62,11 +62,17 @@ void KillRunner::reloadConfiguration()
     }
     m_hasTrigger = !m_triggerWord.isEmpty();
 
-    m_sorting = (Sort) grp.readEntry(CONFIG_SORTING, static_cast<int>(Sort::NONE));
+    m_sorting = (Sort)grp.readEntry(CONFIG_SORTING, static_cast<int>(Sort::NONE));
     QList<Plasma::RunnerSyntax> syntaxes;
-    syntaxes << Plasma::RunnerSyntax(m_triggerWord + QStringLiteral(":q:"),
-                                     i18n("Terminate running applications whose names match the query."));
+    syntaxes << Plasma::RunnerSyntax(m_triggerWord + QStringLiteral(":q:"), i18n("Terminate running applications whose names match the query."));
     setSyntaxes(syntaxes);
+    if (m_hasTrigger) {
+        setTriggerWords({m_triggerWord});
+        setMinLetterCount(minLetterCount() + 2); // Requires two characters after trigger word
+    } else {
+        setMinLetterCount(2);
+        setMatchRegex(QRegularExpression());
+    }
 }
 
 void KillRunner::prep()
@@ -93,10 +99,6 @@ void KillRunner::cleanup()
 void KillRunner::match(Plasma::RunnerContext &context)
 {
     QString term = context.query();
-    if (m_hasTrigger && !term.startsWith(m_triggerWord, Qt::CaseInsensitive)) {
-        return;
-    }
-
     m_prepLock.lockForRead();
     if (!m_processes) {
         m_prepLock.unlock();
@@ -112,10 +114,6 @@ void KillRunner::match(Plasma::RunnerContext &context)
 
     term = term.right(term.length() - m_triggerWord.length());
 
-    if (term.length() < 2)  {
-        return;
-    }
-
     QList<Plasma::QueryMatch> matches;
     const QList<KSysGuard::Process *> processlist = m_processes->getAllProcesses();
     for (const KSysGuard::Process *process : processlist) {
@@ -134,6 +132,7 @@ void KillRunner::match(Plasma::RunnerContext &context)
         match.setIconName(QStringLiteral("application-exit"));
         match.setData(pid);
         match.setId(name);
+        match.setActions(m_actionList);
 
         // Set the relevance
         switch (m_sorting) {
@@ -164,7 +163,7 @@ void KillRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMa
     if (match.selectedAction()) {
         signal = match.selectedAction()->data().toInt();
     } else {
-        signal = 9; //default: SIGKILL
+        signal = 9; // default: SIGKILL
     }
 
     const QStringList args = {QStringLiteral("-%1").arg(signal), QString::number(pid)};
@@ -181,11 +180,4 @@ void KillRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMa
     killAction.execute();
 }
 
-QList<QAction*> KillRunner::actionsForMatch(const Plasma::QueryMatch &match)
-{
-    Q_UNUSED(match)
-
-    return m_actionList;
-}
-
 #include "killrunner.moc"
