@@ -25,16 +25,15 @@ class LocationsRunner : public Plasma::AbstractRunner
 {
     Q_OBJECT
 
-    public:
-        LocationsRunner(QObject *parent, const QVariantList& args);
-        ~LocationsRunner() override;
+public:
+    LocationsRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    ~LocationsRunner() override;
 
-        void match(Plasma::RunnerContext &context) override;
-        void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) override;
+    void match(Plasma::RunnerContext &context) override;
+    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) override;
 
-    protected Q_SLOTS:
-        QMimeData * mimeDataForMatch(const Plasma::QueryMatch &match) override;
+protected Q_SLOTS:
+    QMimeData *mimeDataForMatch(const Plasma::QueryMatch &match) override;
 };
 
-
 #endif
