@@ -27,24 +27,26 @@
 #include <QIcon>
 #include <QMimeData>
 #include <QUrl>
-#include <KRun>
+
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
+#include <KNotificationJobUiDelegate>
 
 K_EXPORT_PLASMA_RUNNER_WITH_JSON(PlacesRunner, "plasma-runner-places.json")
 
-//Q_DECLARE_METATYPE(Plasma::RunnerContext)
-PlacesRunner::PlacesRunner(QObject* parent, const QVariantList &args)
-        : Plasma::AbstractRunner(parent, args)
+// Q_DECLARE_METATYPE(Plasma::RunnerContext)
+PlacesRunner::PlacesRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : Plasma::AbstractRunner(parent, metaData, args)
 {
     setObjectName(QStringLiteral("Places"));
     Plasma::RunnerSyntax defaultSyntax(i18n("places"), i18n("Lists all file manager locations"));
-    setDefaultSyntax(defaultSyntax);
     addSyntax(defaultSyntax);
     addSyntax(Plasma::RunnerSyntax(QStringLiteral(":q:"), i18n("Finds file manager locations that match :q:")));
 
     // ensure the bookmarkmanager, etc. in the places model gets creates created in the main thread
     // otherwise crashes ensue
     m_helper = new PlacesRunnerHelper(this);
+    setMinLetterCount(3);
 }
 
 PlacesRunner::~PlacesRunner()
@@ -55,27 +57,28 @@ void PlacesRunner::match(Plasma::RunnerContext &context)
 {
     if (QThread::currentThread() == QCoreApplication::instance()->thread()) {
         // from the main thread
-        //qDebug() << "calling";
+        // qDebug() << "calling";
         m_helper->match(&context);
     } else {
         // from the non-gui thread
-        //qDebug() << "emitting";
+        // qDebug() << "emitting";
         emit doMatch(&context);
     }
-    //m_helper->match(c);
+    // m_helper->match(c);
 }
 
 PlacesRunnerHelper::PlacesRunnerHelper(PlacesRunner *runner)
     : QObject(runner)
 {
     Q_ASSERT(QThread::currentThread() == QCoreApplication::instance()->thread());
-    connect(runner, &PlacesRunner::doMatch,
-            this, &PlacesRunnerHelper::match,
-            Qt::BlockingQueuedConnection);
+    connect(runner, &PlacesRunner::doMatch, this, &PlacesRunnerHelper::match, Qt::BlockingQueuedConnection);
 
     connect(&m_places, &KFilePlacesModel::setupDone, this, [this](const QModelIndex &index, bool success) {
         if (success && m_pendingUdi == m_places.deviceForIndex(index).udi()) {
-            new KRun(m_places.url(index), nullptr);
+            auto *job = new KIO::OpenUrlJob(m_places.url(index));
+            job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoErrorHandlingEnabled));
+            job->setRunExecutables(false);
+            job->start();
         }
         m_pendingUdi.clear();
     });
@@ -89,11 +92,6 @@ void PlacesRunnerHelper::match(Plasma::RunnerContext *c)
     }
 
     const QString term = context.query();
-
-    if (term.length() < 3) {
-        return;
-    }
-
     QList<Plasma::QueryMatch> matches;
     const bool all = term.compare(i18n("places"), Qt::CaseInsensitive) == 0;
     for (int i = 0; i <= m_places.rowCount(); i++) {
@@ -120,11 +118,11 @@ void PlacesRunnerHelper::match(Plasma::RunnerContext *c)
             // Add category as subtext so one can tell "Pictures" folder from "Search for Pictures"
             // Don't add it if it would match the category ("Places") of the runner to avoid "Places: Pictures (Places)"
             const QString groupName = m_places.data(current_index, KFilePlacesModel::GroupRole).toString();
-            if (!groupName.isEmpty() && !static_cast<PlacesRunner *>(parent())->categories().contains(groupName)) {
+            if (!groupName.isEmpty() && static_cast<PlacesRunner *>(parent())->name() != groupName) {
                 match.setSubtext(groupName);
             }
 
-            //if we have to mount it set the device udi instead of the URL, as we can't open it directly
+            // if we have to mount it set the device udi instead of the URL, as we can't open it directly
             if (m_places.isDevice(current_index) && m_places.setupNeeded(current_index)) {
                 const QString udi = m_places.deviceForIndex(current_index).udi();
                 match.setId(udi);
@@ -159,9 +157,13 @@ void PlacesRunnerHelper::openDevice(const QString &udi)
 void PlacesRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action)
 {
     Q_UNUSED(context);
-    //I don't just pass the model index because the list could change before the user clicks on it, which would make everything go wrong. Ideally we don't want things to go wrong.
+    // I don't just pass the model index because the list could change before the user clicks on it, which would make everything go wrong. Ideally we don't want
+    // things to go wrong.
     if (action.data().type() == QVariant::Url) {
-        new KRun(action.data().toUrl(), nullptr);
+        auto *job = new KIO::OpenUrlJob(action.data().toUrl());
+        job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoErrorHandlingEnabled));
+        job->setRunExecutables(false);
+        job->start();
     } else if (action.data().canConvert<QString>()) {
         m_helper->openDevice(action.data().toString());
     }
