@@ -23,31 +23,42 @@
 #include <KRunner/AbstractRunner>
 #include <QDBusConnection>
 
-typedef QMap< QString, QString > StringStringMap;
+class SessionManagement;
+
+struct RunnerKeyword {
+    QString triggerWord;
+    QString translatedTriggerWord;
+    bool supportPartialMatch = true;
+};
 
 class PowerDevilRunner : public Plasma::AbstractRunner
 {
-        Q_OBJECT
+    Q_OBJECT
+public:
+    PowerDevilRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    ~PowerDevilRunner() override;
 
-    public:
-        PowerDevilRunner( QObject *parent, const QVariantList &args );
-        ~PowerDevilRunner() override;
+    void match(Plasma::RunnerContext &context) override;
+    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) override;
 
-        void match( Plasma::RunnerContext &context ) override;
-        void run( const Plasma::RunnerContext &context, const Plasma::QueryMatch &action ) override;
+private Q_SLOTS:
+    void updateStatus();
 
-    private Q_SLOTS:
-        void updateStatus();
+private:
+    void initUpdateTriggers();
+    void updateSyntaxes();
+    void addSuspendMatch(int value, QList<Plasma::QueryMatch> &matches, Plasma::QueryMatch::Type type);
+    // Returns -1 if there is no match, otherwise the percentage that the user has entered
+    int matchesScreenBrightnessKeywords(const QString &query) const;
+    bool matchesRunnerKeywords(const QList<RunnerKeyword> &keywords, Plasma::QueryMatch::Type &type, const QString &query) const;
+    void addSyntaxForKeyword(const QList<RunnerKeyword> &keywords, const QString &description);
 
-    private:
-        void initUpdateTriggers();
-        void updateSyntaxes();
-        void addSuspendMatch(int value, QList<Plasma::QueryMatch> &matches);
-        bool parseQuery(const QString& query, const QList<QRegExp>& rxList, QString& parameter) const;
-
-        int m_shortestCommand;
+    SessionManagement *m_session;
+    RunnerKeyword m_suspend, m_toRam;
+    RunnerKeyword m_sleep;
+    RunnerKeyword m_hibernate, m_toDisk;
+    RunnerKeyword m_dimScreen;
+    RunnerKeyword m_screenBrightness;
 };
 
-Q_DECLARE_METATYPE(StringStringMap)
-
 #endif
