@@ -24,20 +24,19 @@
 
 #include <QIcon>
 
-class RecentDocuments : public Plasma::AbstractRunner {
+class RecentDocuments : public Plasma::AbstractRunner
+{
     Q_OBJECT
 
-    public:
-        RecentDocuments( QObject *parent, const QVariantList& args );
-        ~RecentDocuments() override;
+public:
+    RecentDocuments(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    ~RecentDocuments() override;
 
-        void match(Plasma::RunnerContext &context) override;
-        void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match) override;
+    void match(Plasma::RunnerContext &context) override;
+    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match) override;
 
-    private Q_SLOTS:
-        QList<QAction *> actionsForMatch(const Plasma::QueryMatch &match) override;
-        QMimeData * mimeDataForMatch(const Plasma::QueryMatch &match) override;
+private Q_SLOTS:
+    QMimeData *mimeDataForMatch(const Plasma::QueryMatch &match) override;
 };
 
-
 #endif
